@@ -20,6 +20,9 @@
 #include "windowshadow.h"
 #include "boxshadowrenderer.h"
 #include <QDebug>
+#include <QCoreApplication>
+#include <QDBusInterface>
+
 
 enum {
     ShadowNone,
@@ -106,7 +109,28 @@ void WindowShadow::classBegin()
 
 void WindowShadow::componentComplete()
 {
+    
     configureTiles();
+    
+    
+    
+    auto chromeInterface = new QDBusInterface ("org.cask.Server",
+                                               "/Chrome",
+                                               "org.cask.Chrome",
+                                               QDBusConnection::sessionBus(), this);
+    qDebug() << "TRYING TO HOOK TO THE CASKSERVER" << qApp->desktopFileName() << qApp->desktopFileName();
+    
+    if(chromeInterface->isValid())
+    {
+        qDebug() << "TRYING TO HOOK TO THE CASKSERVER IS VAL:ID";
+        
+        chromeInterface->call("dropShadow", static_cast<int>(m_radius), qApp->desktopFileName());
+        chromeInterface->call("blurBackground", static_cast<int>(m_radius), qApp->desktopFileName());
+    }else
+    {
+        qDebug() << "COULD NTO HOOK TO THE CASKSERVER";
+    }
+    
 }
 
 void WindowShadow::setView(QWindow *view)
